<template>
    <div class="fullheight">
        <el-form ref="form" :inline="true" :model="sizeForm" label-width="70px">
            <el-form-item label="机组名称" label-width="85px">
                <el-select clearable v-model="params.fanCode" style="width: 150px">
                    <el-option v-for="item in options" :key="item.value" :label="item.label"
                        :value="item.value"></el-option>
                </el-select>
            </el-form-item>
            <el-form-item label="日期" label-width="85px">
                <el-date-picker v-model="params.collTime" type="date" value-format="yyyy-MM-dd" format="yyyy/MM/dd"
                    placeholder="选择日期" style="width: 150px">
                </el-date-picker>
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" @click="onClickSearch">查询</el-button>
                <el-button type="primary" icon="el-icon-refresh" @click="onClickRefresh">重置</el-button>
            </el-form-item>
        </el-form>
        <div class="content">
            <div class="table-form">
                <el-table :data="realWarn" height="100%" fixed>
                    <el-table-column prop="alarmNo" min-width="100" label="预警编号" sortable show-overflow-tooltip
                        align="center">
                    </el-table-column>
                    <el-table-column prop="fanName" sortable min-width="50" show-overflow-tooltip label="机组名称"
                        align="center">
                    </el-table-column>
                    <el-table-column prop="collTime" sortable show-overflow-tooltip label="预警时间" align="center">
                    </el-table-column>
                    <el-table-column prop="modelCname" sortable show-overflow-tooltip label="模型名称" min-width="120"
                        align="center">
                    </el-table-column>
                    <el-table-column label="关联部位" sortable prop="partName" show-overflow-tooltip align="center">
                    </el-table-column>
                    <el-table-column prop="alarmInfo" sortable show-overflow-tooltip label="预警信息" min-width="120"
                        align="center">
                    </el-table-column>
                    <el-table-column prop="resultStatus" sortable show-overflow-tooltip label="预警等级" align="center">
                    </el-table-column>
                </el-table>
                <el-pagination small align="right" class="table-page" @size-change="handleSizeChange"
                    @current-change="handleCurrentChange" :current-page="pageBean.page" :pager-count="11"
                    :page-sizes="[10, 20, 50, 100, 200, 300, 500]" :page-size="pageBean.pageSize"
                    layout="total, sizes, prev, pager, next, jumper" :total="total">
                </el-pagination>
            </div>
        </div>
    </div>
</template>
<script>
import req from '@/api/biz/statePrediction.js'
export default {
    name: 'fault-early-warning',
    data() {
        return {
            dialogVisible: false,
            realWarn: [], //实时预警详情
            pageBean: {
                page: 1,
                pageSize: 50,
            },
            params: {
                fanCode: '', //机组号
                collTime: '', //查询时间
            },
            sizeForm: {
                name: '',
                model: '',
            },
            options: [], //机组号字段
            total: 0,
            dateTime: '',
        }
    },
    created() {
        this.getDateTime()
        this.getWindData()
        this.getRealWarn()
    },
    methods: {
        // 查询
        onClickSearch() {
            this.pageBean.page = 1
            this.getRealWarn()
        },
        // 重置
        onClickRefresh() {
            this.params.fanCode = ''
            this.params.collTime = this.dateTime
            this.getRealWarn()
        },
        // 获取当前日期
        getDateTime() {
            let yesterday = new Date().getTime() - 24 * 60 * 60 * 1000
            let date = new Date(yesterday)
            var year = date.getFullYear()
            var month = date.getMonth() + 1
            var day = date.getDate()
            if (month >= 1 && month <= 9) {
                month = '0' + month
            }
            if (day >= 0 && day <= 9) {
                day = '0' + day
            }
            this.dateTime = year + '-' + month + '-' + day
            this.params.collTime = this.dateTime
        },
        // 获取实时预警详情
        getRealWarn() {
            let dateTime = this.dateTime
            if (this.params.collTime) {
                dateTime = this.params.collTime
            }
            let data = {
                pageBean: this.pageBean,
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'collTime',
                        relation: 'AND',
                        value: dateTime,
                    },
                ],
                sorter: [
                    {
                        direction: 'DESC', property: 'f.coll_time_'
                    }]
            }
            if (this.params.fanCode) {
                data = {
                    pageBean: this.pageBean,
                    querys: [
                        {
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'fanCode',
                            relation: 'AND',
                            value: this.params.fanCode,
                        },
                    ],
                }
            }
            if (this.params.fanCode && this.params.collTime) {
                data = {
                    pageBean: this.pageBean,
                    querys: [
                        {
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'f.fan_code_',
                            relation: 'AND',
                            value: this.params.fanCode,
                        },
                        {
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'f.coll_time_',
                            relation: 'AND',
                            value: this.params.collTime,
                        },
                    ],
                }
            }
            req.getRealWarn(data).then((res) => {
                // console.log(res, '实时预警详情')
                if (res && res.rows) {
                    this.realWarn = res.rows
                    this.total = res.total
                }

            })
        },
        handleSizeChange(val) {
            this.pageBean.pageSize = val
            this.getRealWarn()
        },

        handleCurrentChange(val) {
            this.pageBean.page = val
            this.getRealWarn()
        },

        getWindData() {
            let query = {
                sorter: [{ direction: 'ASC', property: 'fanCode' }],
            }
            this.$http
                .post('${cssc}/biz/base/fanInfo/v1/list', query)
                .then((resp) => {
                    let row = resp.data
                    for (var i = 0; i < row.length; i++) {
                        let obj = {}
                        obj.label = row[i].fanName
                        obj.value = row[i].fanCode
                        this.options.push(obj)
                    }
                })
        },
    },
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';
// 表头背景颜色
$table-header: #ffc000;
// 行背景颜色
$table-tr: #fff2cc;
//标题粗体的颜色
$font-title: rgb(78, 77, 77);

.content {
    height: calc(100% - 75px);
}

.table-form {
    height: 100%;
}

/deep/ .el-dialog {
    border: 1px solid $--hover-bgcolor;
    background: transparent;
}

/deep/ .el-dialog__header {
    background: #116179 !important;
    padding: 8px 20px !important;
}

/deep/ .el-dialog__title {
    font-size: 14px;
    font-weight: bold;
    color: #fff;
}

/deep/ .el-icon-close:before {
    color: #fff;
    font-weight: bold;
    font-size: 18px;
}

/deep/ .el-dialog__body {
    height: 300px;
    padding: 15px;
    background-color: #14364d;
}

/deep/ .el-form-item__label {
    color: $--color-text;
}

/deep/ .el-table__body-wrapper {
    background: $--background-color-secondary;
}

/deep/ .el-pagination {
    padding: 10px 5px 8px 5px;
}

/deep/ .el-input--mini .el-input__inner {
    height: 22px;
}

/deep/ .el-form-item {
    margin-bottom: 10px;
}
</style>
